@@ -5,11 +5,11 @@ import skbio
 import numpy as np
 from collections import Counter
 from skbio import Protein
-from ingenannot.Commands.Command import Command
-from ingenannot.Utils import Utils
+from ingenannot.commands.command import Command
+from ingenannot.utils import Utils
 from math import *
 
-from ingenannot.Entities.CDS import CDS
+from ingenannot.entities.cds import CDS
 
 class AddIsoforms(Command):
 
