@@ -302,13 +302,14 @@ class Select(Command):
         if self.nbsrc_absolute > 1:
             metagenes = self.filter_metagenes_required_number_sources(metagenes)
         nb_removed_metagenes = nb_metagenes - len(metagenes)
-
         if not self.noaed:
-            metagenes = AnnotEditDistance.compute_aed(metagenes, self.transcript_gff_file, self.transcript_gff_file_stranded, self.transcript_gff_file_source, self.penalty_overflow, evtype="tr", cds_only=self.aed_tr_cds_only, procs=Command.NB_CPUS)
-            metagenes = AnnotEditDistance.compute_aed(metagenes, self.protein_gff_file, self.protein_gff_file_stranded, self.protein_gff_file_source, 0.0, evtype="pr", procs=Command.NB_CPUS)
+            for metag in metagenes:
+                metag.genes = AnnotEditDistance.compute_aed(metag.genes, self.transcript_gff_file, self.transcript_gff_file_stranded, self.transcript_gff_file_source, self.penalty_overflow, evtype="tr", cds_only=self.aed_tr_cds_only, procs=Command.NB_CPUS)
 
-            if self.longread_gff_file:
-                metagenes = AnnotEditDistance.compute_aed(metagenes, self.longread_gff_file, True, self.longread_gff_file_source, self.longread_penalty_overflow, evtype="lg", cds_only=self.aed_tr_cds_only, procs=Command.NB_CPUS)
+                metag.genes = AnnotEditDistance.compute_aed(metag.genes, self.protein_gff_file, self.protein_gff_file_stranded, self.protein_gff_file_source, 0.0, evtype="pr", procs=Command.NB_CPUS)
+
+                if self.longread_gff_file:
+                    metag.genes = AnnotEditDistance.compute_aed(metag.genes, self.longread_gff_file, True, self.longread_gff_file_source, self.longread_penalty_overflow, evtype="lg", cds_only=self.aed_tr_cds_only, procs=Command.NB_CPUS)
 
         transcripts, transcripts_not_exported = self.filter(metagenes, nb_removed_metagenes)
 
@@ -324,7 +325,6 @@ class Select(Command):
                     transcripts.append(rescue_tr[0])
                 else:
 
-                    #transcripts_not_exported.extend(strfr_transcripts_not_exported)
                     transcripts_not_exported.append(strfr)
 
             # rescue transcript if a non-overlapp
