@@ -6,7 +6,6 @@ Class entity: Transcript
 import pysam
 import logging
 import numpy as np
-
 from ingenannot.entities.intron import Intron
 from ingenannot.entities.cds import CDS
 
@@ -254,7 +253,8 @@ class Transcript():
         min_pos, max_pos = self.__get_boundaries_for_comparison(other,self_no_utr, other_no_utr)
         self_bits = self.get_bit_repr_for_comparison(min_pos, max_pos, self_no_utr)
         other_bits = other.get_bit_repr_for_comparison(min_pos, max_pos, other_no_utr)
-        return bin(int(self_bits,2) & int(other_bits,2)).count("1")
+
+        return bin(self_bits & other_bits).count("1")
 
     def get_nb_specific_bases_vs_another_transcript(self, other, self_no_utr=False, other_no_utr=False):
         """get nb of specific bases with another transcipt"""
@@ -270,7 +270,7 @@ class Transcript():
         self_bits = self.get_bit_repr_for_comparison(min_pos, max_pos, self_no_utr)
         other_bits = other.get_bit_repr_for_comparison(min_pos, max_pos, other_no_utr)
 
-        return bin(int(self_bits,2) & (~ int(other_bits,2))).count("1")
+        return bin(self_bits & (~ other_bits)).count("1")
 
     def get_nb_specific_bases_vs_another_transcript_specific_positions(self, other, start, end, self_no_utr=False, other_no_utr=False):
         """get nb of specific bases with another transcipt with specific start and end"""
@@ -283,7 +283,7 @@ class Transcript():
         self_bits = self.get_bit_repr_for_comparison_spe(start, end, self_no_utr)
         other_bits = other.get_bit_repr_for_comparison_spe(start, end, other_no_utr)
 
-        return bin(int(self_bits,2) & (~ int(other_bits,2))).count("1")
+        return bin(self_bits & (~ other_bits)).count("1")
 
 
     def __get_boundaries_for_comparison(self, other, self_no_utr=False, other_no_utr=False):
@@ -325,7 +325,6 @@ class Transcript():
             lFeatures = self.lCDS
         else:
             lFeatures = self.lExons
-
         for feat in lFeatures:
             for pos in range(feat.start,feat.end+1):
                     bitarray[pos-min_pos] = code
@@ -335,7 +334,7 @@ class Transcript():
 
     def get_bit_repr_for_comparison(self,min_pos, max_pos, no_utr, code=1):
 
-        bitarray = [0]*(max_pos-min_pos+1)
+        bitarray = 0
 
         if no_utr:
             lFeatures = self.lCDS
@@ -344,13 +343,15 @@ class Transcript():
 
         for feat in lFeatures:
             for pos in range(feat.start,feat.end+1):
-                    bitarray[pos-min_pos] = code
+                    #bitarray[pos-min_pos] = code
+                    bitarray = bitarray | (1 << pos-min_pos) 
+        
+        return bitarray
 
-        return "".join([str(x) for x in bitarray])
 
     def get_bit_repr_for_comparison_spe(self,min_pos, max_pos, no_utr):
 
-        bitarray = [0]*(max_pos-min_pos+1)
+        bitarray = 0
 
         if no_utr:
             lFeatures = self.lCDS
@@ -360,9 +361,9 @@ class Transcript():
         for feat in lFeatures:
             for pos in range(feat.start,feat.end+1):
                 if (pos >= min_pos) & (pos <= max_pos):
-                    bitarray[pos-min_pos] = 1
+                    bitarray = bitarray | (1 << pos-min_pos) 
 
-        return "".join([str(x) for x in bitarray])
+        return bitarray 
 
 
     def has_same_exons(self, other):
