@@ -958,6 +958,13 @@ class ArgParse():
                 help="File of files, <GFF with AED tags>TAB<source>",
                 type=str
         )
+        sbp.add_argument(
+                "-s","--statistics",
+                help='Perform statistics on aed scores between sources \
+                      , default=False',
+                action="store_true",
+                default=False
+        )
         sbp.set_defaults(command=cmd.AEDCompare)
 
         return sbp
