@@ -64,7 +64,6 @@ class Utils(object):
             except Exception as  e:
                 logging.error(str(e))
         logging.info("Gaeval infos extracted from {} transcripts".format(len(all_gaeval_infos)))
-        #print(all_gaeval_infos)
         return all_gaeval_infos
 
 
@@ -90,7 +89,6 @@ class Utils(object):
 
         for g in genes:
             for tr in g.lTranscripts:
-                #print(gaeval_infos)
                 if (tr.id,tr.source) in gaeval_infos:
                     tr.add_gaeval_infos(gaeval_infos[(tr.id,tr.source)])
                 else:
@@ -308,7 +306,6 @@ class Utils(object):
         clusters_ref.sort(key=lambda x: x.start)
         for cl in clusters_ref:
             merge = False
-#            print(cl)
             for i,cl2 in enumerate(merged_clusters_ref):
 #                if cl2.is_cluster_spanning(cl, stranded=stranded):
                 if cl2.is_cluster_spanning_min_cov(cl, stranded=stranded, cov=0.1):
@@ -317,7 +314,6 @@ class Utils(object):
                     break
             if not merge:
                 merged_clusters_ref.append(cl)
-#            print(merged_clusters_ref[0])
 
         # recursive
         if len(merged_clusters_ref) != len(clusters_ref):
@@ -353,7 +349,7 @@ class Utils(object):
         result = func(*args)
         return result
 
-    def get_metagenes_from_clusters(clusters):
+    def get_metagenes_from_clusters_old(clusters):
 
         lMetagenes = []
         for i,cl in enumerate(clusters):
@@ -369,6 +365,24 @@ class Utils(object):
             lMetagenes.append(m)
         return lMetagenes
 
+    def get_metagenes_from_clusters(clusters):
+
+        lMetagenes = []
+        for i,cl in enumerate(clusters):
+            seqid = cl.seqid
+            start = min([gene.start for gene in cl.genes])
+            end = max([gene.end for gene in cl.genes])
+            transcripts = []
+            for gene in cl.genes:
+                transcripts.extend(gene.lTranscripts)
+            m = MetaGene(i,seqid, start, end, transcripts)
+            # DEBUG add for comapre (test recursif !!!)
+            m.genes = cl.genes
+            lMetagenes.append(m)
+        return lMetagenes
+
+
+
     @staticmethod
     def statistics(genes, genome=''):
         '''Compute gene metrics'''
@@ -378,7 +392,6 @@ class Utils(object):
         len_genes = sorted([g.end -g.start +1 for g in genes])
         metrics['average_gene_length'] = sum(len_genes)/len(len_genes)
         metrics['median_gene_length'] = len_genes[int(len(len_genes)/2)]
-        #print(len_genes[0:400])
         metrics['min_gene_length'] = len_genes[0]
         metrics['max_gene_length'] =  len_genes[-1]
         len_transcripts = []
@@ -425,7 +438,6 @@ class Utils(object):
         metrics['median_intron_length'] = len_introns[int(len(len_introns)/2)]
         metrics['min_intron_length'] = len_introns[0]
         metrics['max_intron_length'] = len_introns[-1]
-        #print(len_introns[-100:])
         len_CDS = []
         CDS_completness = []
         for g in genes:
@@ -617,31 +629,19 @@ class Utils(object):
 
         references = list(set([g.seqid for g in genes]))
         Utils.natural_sort(references)
-        #print(references)
         intergenic_regions = []
-#        for ref in ['chr_6']:
         for ref in references:
-#        for ref in references[0:1]:
             if ref not in seqs:
                 raise Exception("Error genes on unknown sequence")
 
             start = 1
-#            start = 987000 
-#            start = 402000 
             for g in sorted([g for g in genes if g.seqid == ref], key=lambda x: x.get_min_cds_start()):
-#            for g in sorted([g for g in genes if g.seqid == ref and g.start > 980000 and g.end < 1000000], key=lambda x: x.get_min_cds_start()):
-#            for g in sorted([g for g in genes if g.seqid == ref and g.start > 400000 and g.end < 474000], key=lambda x: x.get_min_cds_start()):
-#                print(g.gene_id)
-            #for g in sorted([g for g in genes[0:100] if g.seqid == ref], key=lambda x: x.get_min_cds_start()):
                 if g.get_min_cds_start()-1 > start:
                     if g.get_min_cds_start() - start > min_len:
                         intergenic_regions.append((g.seqid, start, g.get_min_cds_start()-1))
-#                    print("{}\t{}\t{}".format(g.seqid, start, g.get_min_cds_start()-1))
                 start = g.get_max_cds_end() + 1
-#        print(intergenic_regions)
             if start < seqs[ref] and seqs[ref] - start > min_len:
                 intergenic_regions.append((ref, start, seqs[ref]))
-#                print("{}\t{}\t{}".format(ref, start, seqs[ref]))
         logging.info("{} intergenic regions extracted".format(len(intergenic_regions)))
         return intergenic_regions
 
